@@ -112,6 +112,11 @@ static int amber_BeamPos_exec(cpl_plugin *) ;
 static int amber_BeamPos_destroy(cpl_plugin *) ;
 static int amber_BeamPos(cpl_parameterlist *, cpl_frameset *) ;
 
+static cpl_image * amber_smooth_image_median(
+        const cpl_image     *   in,
+        int                     size_x,
+        int                     size_y);
+
 /* amdlib */
 int amdlibIsJHKMode(amdlibRAW_DATA *data);
 amdlibCOMPL_STAT amdlibExplodeJHKScienceData (amdlibSCIENCE_DATA *srcScienceData, 
@@ -206,6 +211,7 @@ static cpl_error_code amber_propertylist_append(cpl_propertylist * self,
         case CPL_TYPE_CHAR:
             err = cpl_propertylist_append_char(self, name,
                                                cpl_property_get_char(prop));
+            break;
         case CPL_TYPE_BOOL:
             err = cpl_propertylist_append_bool(self, name,
                                                cpl_property_get_bool(prop));
@@ -708,7 +714,8 @@ static int CalculateQCParams( const cpl_image * pImage,
 	  
 	  /* Filter out hot/cold pixels */
 	  temp = pFiltered;
-	  pFiltered = cpl_image_filter_median( temp, kernel_7x1 );
+	  pFiltered=amber_smooth_image_median(temp, median_filter_x, 1);
+	  //pFiltered = cpl_image_filter_median( temp, kernel_7x1 );
 	  cpl_image_delete( temp );
 
 	  if (debug) cpl_image_save( pFiltered , "/tmp/backsub2_filtered.fits", 
@@ -1079,9 +1086,10 @@ static int amber_BeamPos(
    *
   */
 
-  cur_frame = cpl_frameset_get_first( framelist );
+  cpl_frameset_iterator * it = cpl_frameset_iterator_new(framelist);
 
-  while( cur_frame && !iStatus && iFrameCount <22 )
+
+  while( (cur_frame = cpl_frameset_iterator_get(it)) && !iStatus && iFrameCount <22 )
   {
  
    /*  iFrameCount++; Count only "good" frames */
@@ -1274,9 +1282,13 @@ static int amber_BeamPos(
       cpl_msg_info( fctid, "%s", szMessage );   
     } /* Filename and Tag present */    
     
-    cur_frame = cpl_frameset_get_next( framelist );   
+    cpl_frameset_iterator_advance(it, 1);
+
+
   } /* while more frames */
 
+  cpl_frameset_iterator_delete(it);
+
   if( iFrameCount != 22 )
   {
     sprintf( szMessage, "Error: Please input 22 raw files of type AMBER_BEAMPOS", iFrameCount ); 
@@ -1291,6 +1303,34 @@ static int amber_BeamPos(
   
   return iStatus ;
 }
+/*---------------------------------------------------------------------------*/
+/**
+  @brief    Smooth an image using a median filter
+  @param    in      image to be smoothed
+  @param    size_x  size_x of kernel matrix to use in filtering
+  @param    size_y  size_y of kernel matrix to use in filtering
+  @return   out     smoothed image
+ */
+/*---------------------------------------------------------------------------*/
+static cpl_image * amber_smooth_image_median(
+        const cpl_image     *   in,
+        int                     size_x,
+        int                     size_y)
+{
+    cpl_image * out = cpl_image_duplicate(in);
+    cpl_mask * kernel = cpl_mask_new(size_x, size_y);
+    cpl_mask_not(kernel);
+
+    if(cpl_image_filter_mask(out, in, kernel, CPL_FILTER_MEDIAN,
+                             CPL_BORDER_FILTER) != CPL_ERROR_NONE) {
+        cpl_image_delete(out);
+        cpl_mask_delete(kernel);
+        return NULL;
+    }
+
+    cpl_mask_delete(kernel);
+    return (out);
+}
 
 
 
