@@ -1077,7 +1077,7 @@ static int amber_SciCal_create(cpl_plugin * plugin)
 	//	p = cpl_parameter_new_value("amber.amber_SciCal.value_NO_BIAS", CPL_TYPE_DOUBLE, "TBD", "amber.amber_SciCal",0.0);
 	//	cpl_parameter_set_alias(p, CPL_PARAMETER_MODE_CLI,"value_NO_BIAS");
 	//	cpl_parameterlist_append(recipe->parameters, p);
-	p = cpl_parameter_new_value("amber.amber_SciCal.value_DROP", CPL_TYPE_DOUBLE, "TBD", "amber.amber_SciCal",0);
+	p = cpl_parameter_new_value("amber.amber_SciCal.value_DROP", CPL_TYPE_DOUBLE, "TBD", "amber.amber_SciCal",0.0);
 	cpl_parameter_set_alias(p, CPL_PARAMETER_MODE_CLI,"value_DROP");
 	cpl_parameterlist_append(recipe->parameters, p);
 	//	p = cpl_parameter_new_value("amber.amber_SciCal.value_NORMALIZE_SPECTRUM", CPL_TYPE_DOUBLE, "TBD", "amber.amber_SciCal",0.0);
